import { __decorate, __metadata, __param } from "tslib";
import { Body, Controller, Get, HttpStatus, Param, Post, Req, Res, Logger } from '@nestjs/common';
import configs from './config';
import moment from 'moment';
import { get } from 'lodash';
import { AppService } from './app.service';
import http from './http';
import extractContent from './extractContent';
import fs from 'fs';
import path from 'path';
try {
    const jsonString = fs.readFileSync(path.join(__dirname, './wdpr-ra-hybrid-manifest.json'));
    const wdprHybirdConfig = JSON.parse(jsonString.toString());
    const { contentUrl, version, resources, hashJwt } = wdprHybirdConfig;
    fs.writeFileSync(path.join(__dirname, './anniversary/wdpr-ra-hybrid-manifest.json'), JSON.stringify({ contentUrl, version, resources, hashJwt }));
}
catch (err) {
    console.log(err);
}
let AppController = class AppController {
    constructor(appSvc) {
        this.appSvc = appSvc;
    }
    error(req, res, body) {
        Logger.error(body);
        res.status(HttpStatus.OK).json({});
    }
    mpropzKey(key, res) {
        res.status(HttpStatus.OK).send(get(configs, key));
    }
    healthCheckShallow(res) {
        res.status(HttpStatus.OK).json({
            health: 0
        });
    }
    healthCheckDeep(res) {
        res.status(HttpStatus.OK).json({
            status: 'UP',
            environment: configs.appEnv,
            applicationVersion: configs.appVersion,
            nodeVersion: process.versions.node,
            serverRunningFrom: moment(configs.startTime).fromNow(),
            serverStartDateTime: moment(configs.startTime).toString(),
            memoryUsage: process.memoryUsage()
        });
    }
    async getAcpContent(lang, res) {
        const apiPath = `${configs.gmsProjectId}/content/${configs.gmsContentId}`;
        const response = await http.get(apiPath);
        const data = get(response, 'data.properties');
        const extractedContent = extractContent(lang)(data);
        res.status(HttpStatus.OK).json(extractedContent);
    }
};
__decorate([
    Post(`${configs.appHome}/error`),
    __param(0, Req()), __param(1, Res()), __param(2, Body()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Object]),
    __metadata("design:returntype", void 0)
], AppController.prototype, "error", null);
__decorate([
    Get(`${configs.appHome}/mpropz/:key`),
    __param(0, Param()), __param(1, Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object]),
    __metadata("design:returntype", void 0)
], AppController.prototype, "mpropzKey", null);
__decorate([
    Get(configs.healthShallowPath),
    __param(0, Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], AppController.prototype, "healthCheckShallow", null);
__decorate([
    Get(configs.healthDeepPath),
    __param(0, Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], AppController.prototype, "healthCheckDeep", null);
__decorate([
    Get(`${configs.appHome}/api/content/:lang`),
    __param(0, Param('lang')), __param(1, Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object]),
    __metadata("design:returntype", Promise)
], AppController.prototype, "getAcpContent", null);
AppController = __decorate([
    Controller(),
    __metadata("design:paramtypes", [AppService])
], AppController);
export { AppController };
//# sourceMappingURL=app.controller.js.map